==> org-lsst-ccs-subsystem-refrig-main-3.0-sources.jar: org/lsst/ccs/subsystem/refrig/LongLines.java <==
package org.lsst.ccs.subsystem.refrig;

import java.io.IOException;
import org.lsst.ccs.command.annotations.Command;
import org.lsst.ccs.command.annotations.Command.CommandType;
import org.lsst.ccs.framework.Module;
import org.lsst.ccs.subsystem.monitor.Alarm;
import org.lsst.ccs.subsystem.monitor.Line;
import org.lsst.ccs.subsystem.monitor.Monitor;
import org.lsst.ccs.subsystem.monitor.data.MonitorFullState;
import org.lsst.ccs.subsystem.refrig.data.RefrigFullState;
import org.lsst.ccs.subsystem.refrig.data.RefrigState;
import org.lsst.ccs.subsystem.refrig.status.RefrigStateStatus;

/**
 ******************************************************************************
 **
 **  Implements the refrigeration long lines test modular subsystem.
 **
 **  @author Owen Saxton
 **
 ******************************************************************************
 */
public class LongLines extends Module implements Monitor.AlarmHandler {

   /**
    ***************************************************************************
    **
    **  Constants.
    **
    ***************************************************************************
    */
    private final static int
        EVENT_ID_MAIN_POWER = 0,
        EVENT_ID_LOAD_POWER = 1;

   /**
    ***************************************************************************
    **
    **  Data fields.
    **
    ***************************************************************************
    */
    Monitor mon;
    String configName = "test";
    boolean coldStart, running, loadAlarm;
    int state = RefrigState.LOAD_POWER_STATE;
    Line mainPowerLine, loadPowerLine;


   /**
    ***************************************************************************
    **
    **  Main constructor.
    **
    ***************************************************************************
    */
    public LongLines(String name, int tickMillis, String configName)
    {
        super(name, tickMillis);
        this.configName = configName;
        String cold = System.getProperty("lsst.ccs.refrig.coldstart", "");
        coldStart = cold.equals("true");
    }


   /**
    ***************************************************************************
    **
    **  Initializes the refrigeration subsystem.
    **
    ***************************************************************************
    */
    @Override
    public void initModule()
    {
        /*
        **  Initialize all configuration data
        */
        mon = new Monitor(this, this, log);
        mon.initConfiguration();
        mainPowerLine = mon.getLine("MainPower");
        loadPowerLine = mon.getLine("LoadPower");

        /*
        **  Initialize the hardware
        */
        if (mainPowerLine != null) {
            mainPowerLine.setWarm(!coldStart);
        }
        mon.initSensors();
        if (mainPowerLine != null) {
            mainPowerLine.setWarm(false);
        }

        /*
        **  Set output lines
        */
        setMainPowerEnable(isMainPowerOn() ? 1 : 0);
        setLoadPower();

        /*
        **  Start the monitoring
        */
        mon.start();
    }


   /**
    ***************************************************************************
    **
    **  Performs periodic trending data broadcast.
    **
    ***************************************************************************
    */
    @Override
    public void tick()
    {
        /*
        **  Broadcast the state if first time
        */
        if (!running) {
//            getSubsystem().switchToEngineeringMode();

            System.out.println("Refrigeration long lines test system started");
            publishState();
            mon.publishState();    // For any GUIs
            mon.publishLimits();   // For GUIs and the trending database
            running = true;
        }

        /*
        **  Broadcast the trending data
        */
        mon.publishData();
    }


   /**
    ***************************************************************************
    **
    **  Sets the tick period.
    **
    **  Overrides the method in Module in order to publish a status update.
    **
    **  @param  value  The tick period (milliseconds) to set.
    **
    ***************************************************************************
    */
    @Command(type=CommandType.ACTION, description="Sets the tick interval")
    @Override
    public void setTickMillis(int value)
    {
        super.setTickMillis(value);
        publishState();
    }


   /**
    ***************************************************************************
    **
    **  Handles alarm events.
    **
    ***************************************************************************
    */
    @Override
    public void processAlarm(int event, int parm)
    {
        switch (event) {

        case Alarm.EVENT_TRIP:
            if (parm == EVENT_ID_MAIN_POWER) {
                if ((state & RefrigState.MAIN_TRIPPED_STATE) == 0) {
                    state |= RefrigState.MAIN_TRIPPED_STATE;
                    setMainPowerEnable(0);
                    publishState();
               }
            }
            else if (parm == EVENT_ID_LOAD_POWER) {
                loadAlarm = true;
                if ((state & RefrigState.LOAD_TRIP_ENAB_STATE) != 0) {
                    state &= ~RefrigState.LOAD_POWER_STATE;
                    setLoadPower();
                    publishState();
                }
            }
            break;
            
        case Alarm.EVENT_RESET:
            if (parm == EVENT_ID_MAIN_POWER) {
                if ((state & RefrigState.MAIN_TRIPPED_STATE) != 0) {
                    state &= ~RefrigState.MAIN_TRIPPED_STATE;
                    publishState();
               }
            }
            if (parm == EVENT_ID_LOAD_POWER) {
                loadAlarm = false;
                if ((state & RefrigState.LOAD_TRIP_ENAB_STATE) != 0) {
                    state |= RefrigState.LOAD_POWER_STATE;
                    setLoadPower();
                    publishState();
                }
            }
            break;

        default:

        }
    }


   /**
    ***************************************************************************
    **
    **  Sets the main power enabled state on or off.
    **
    **  @param  value    The enabled state value to set: 0 = off, ~0 = on.
    **
    **  @param  publish  If true, publish the new state on the status bus.
    **
    ***************************************************************************
    */
    @Command(type=CommandType.ACTION,
             description="Sets the main power enabled state")
    public void setMainPowerEnable(int value)
    {
        if (value != 0) {
            if ((state & RefrigState.MAIN_TRIPPED_STATE) == 0) {
                state |= RefrigState.MAIN_POWER_STATE;
            }
        }
        else {
            state &= ~RefrigState.MAIN_POWER_STATE;
        }
        setMainPower();
        publishState();
    }


   /**
    ***************************************************************************
    **
    **  Sets the load power trip enabled state on or off.
    **
    **  @param  value  The load trip enabled state value to set: 0 = off;
    **                 ~0 = on.
    **
    ***************************************************************************
    */
    @Command(type=CommandType.ACTION,
             description="Sets the load power trip enabled state")
    public void setLoadTripEnable(int value)
    {
        if (value != 0) {
            state |= RefrigState.LOAD_TRIP_ENAB_STATE;
            if (loadAlarm) {
                state &= ~RefrigState.LOAD_POWER_STATE;
                setLoadPower();
            }
        }
        else {
            state &= ~RefrigState.LOAD_TRIP_ENAB_STATE;
            if ((state & RefrigState.LOAD_POWER_STATE) == 0) {
                state |= RefrigState.LOAD_POWER_STATE;
                setLoadPower();
            }
        }
        publishState();
    }


   /**
    ***************************************************************************
    **
    **  Saves the configuration data.
    **
    ***************************************************************************
    */
    @Command(type=CommandType.ACTION,
             description="Saves the current configuration")
    public void saveConfiguration() throws IOException
    {
        register(configName, "");
        mon.clearLimitChanges();
        mon.publishState();     // Must always do this
    }


   /**
    ***************************************************************************
    **
    **  Gets the full state of the refrigeration module.
    **
    **  This is intended to be called by GUIs during initialization
    **
    ***************************************************************************
    */
    @Command(type=CommandType.QUERY,
             description="Gets the full refrigeration state")
    public RefrigFullState getFullState()
    {
        RefrigState refgState = new RefrigState(state, getTickMillis());
        MonitorFullState monState = mon.getFullState();
        return new RefrigFullState(refgState, monState);
    }    


   /**
    ***************************************************************************
    **
    **  Gets the operating state word.
    **
    **  @return  The current value of the operating state
    **
    ***************************************************************************
    */
    int getState()
    {
        return state;
    }


   /**
    ***************************************************************************
    **
    **  Publishes the state of the refrigeration module.
    **
    **  This is intended to be called whenever any element of the state is
    **  changed.
    **
    ***************************************************************************
    */
    void publishState()
    {
        if (running) {
            RefrigState refgState = new RefrigState(state, getTickMillis());
            sendToStatus(new RefrigStateStatus(refgState));
        }
    }    


   /**
    ***************************************************************************
    **
    **  Sets the main power on or off, according to its state.
    **
    ***************************************************************************
    */
    void setMainPower()
    {
        if (mainPowerLine != null) {
            mainPowerLine.set((state & RefrigState.MAIN_POWER_STATE) != 0);
        }
    }
            

   /**
    ***************************************************************************
    **
    **  Sets the load power on or off, according to its state.
    **
    ***************************************************************************
    */
    void setLoadPower()
    {
        if (loadPowerLine != null) {
            loadPowerLine.set((state & RefrigState.LOAD_POWER_STATE) != 0);
        }
    }


   /**
    ***************************************************************************
    **
    **  Gets the hardware main power state
    **
    ***************************************************************************
    */
    boolean isMainPowerOn()
    {
        return mainPowerLine != null && mainPowerLine.isSet();
    }
            

   /**
    ***************************************************************************
    **
    **  Gets the hardware load power state
    **
    ***************************************************************************
    */
    boolean isLoadPowerOn()
    {
        return loadPowerLine != null && loadPowerLine.isSet();
    }
    
}

==> org-lsst-ccs-subsystem-refrig-main-3.1.0-sources.jar: org/lsst/ccs/subsystem/refrig/LongLines.java <==
package org.lsst.ccs.subsystem.refrig;

import java.io.IOException;
import org.lsst.ccs.command.annotations.Command;
import org.lsst.ccs.command.annotations.Command.CommandType;
import org.lsst.ccs.framework.HardwareController;
import org.lsst.ccs.framework.Module;
import org.lsst.ccs.framework.TreeWalkerDiag;
import org.lsst.ccs.subsystem.monitor.Alarm;
import org.lsst.ccs.subsystem.monitor.Line;
import org.lsst.ccs.subsystem.monitor.Monitor;
import org.lsst.ccs.subsystem.monitor.data.MonitorFullState;
import org.lsst.ccs.subsystem.refrig.data.RefrigFullState;
import org.lsst.ccs.subsystem.refrig.data.RefrigState;

/**
 ******************************************************************************
 **
 **  Implements the refrigeration long lines test modular subsystem.
 **
 **  @author Owen Saxton
 **
 ******************************************************************************
 */
public class LongLines extends Module
                       implements HardwareController, Monitor.AlarmHandler {

   /**
    ***************************************************************************
    **
    **  Constants.
    **
    ***************************************************************************
    */
    private final static int
        EVENT_ID_MAIN_POWER = 0,
        EVENT_ID_LOAD_POWER = 1;

   /**
    ***************************************************************************
    **
    **  Data fields.
    **
    ***************************************************************************
    */
    Monitor mon;
    String configName = "test";
    boolean coldStart, loadAlarm;
    int state = RefrigState.LOAD_POWER_STATE;
    Line mainPowerLine, loadPowerLine;


   /**
    ***************************************************************************
    **
    **  Main constructor.
    **
    **  @param  name        The subsystem name
    **
    **  @param  tickMillis  The tick period (ms)
    **
    **  @param  configName  The name of the configuration
    **
    ***************************************************************************
    */
    public LongLines(String name, int tickMillis, String configName)
    {
        super(name, tickMillis);
        this.configName = configName;
        String cold = System.getProperty("lsst.ccs.refrig.coldstart", "");
        coldStart = cold.equals("true");
    }


   /**
    ***************************************************************************
    **
    **  Initializes the refrigeration subsystem.
    **
    ***************************************************************************
    */
    @Override
    public void initModule()
    {
        /*
        **  Initialize all configuration data
        */
        mon = new Monitor(this, this, log);
        mon.initConfiguration();

        /*
        **  Get output lines to be used
        */
        mainPowerLine = mon.getLine("MainPower");
        if (mainPowerLine == null) {
            log.error("Main power line (MainPower) not defined");
        }
        loadPowerLine = mon.getLine("LoadPower");
        if (loadPowerLine == null) {
            log.error("Load power line (LoadPower) not defined");
        }
    }


   /**
    ***************************************************************************
    **
    **  Initializes the hardware.
    **
    **  @return  GO
    **
    ***************************************************************************
    */
    @Override
    public TreeWalkerDiag checkHardware()
    {
        System.out.println("checkHardware was called");

        /*
        **  Initialize the hardware
        */
        if (mainPowerLine != null) {
            mainPowerLine.setWarm(!coldStart);
        }
        mon.initSensors();
        if (mainPowerLine != null) {
            mainPowerLine.setWarm(false);
        }

        /*
        **  Set output lines
        */
        setMainPowerEnable(isMainPowerOn() ? 1 : 0);
        setLoadPower();

        return TreeWalkerDiag.GO;
    }


   /**
    ***************************************************************************
    **
    **  Checks whether hardware is started.
    **
    ***************************************************************************
    */
    @Override
    public void checkStarted()
    {
        System.out.println("checkStarted was called");
    }


   /**
    ***************************************************************************
    **
    **  Checks whether hardware is stopped.
    **
    ***************************************************************************
    */
    @Override
    public void checkStopped()
    {
        System.out.println("checkStopped was called");
    }


   /**
    ***************************************************************************
    **
    **  Starts the subsystem.
    **
    ***************************************************************************
    */
    @Override
    public void startTicking()
    {
        mon.start();
        super.startTicking();
        publishState();
        mon.publishState();    // For any GUIs
        mon.publishLimits();   // For GUIs and the trending database
        System.out.println("Refrigeration long lines test system started");
    }


   /**
    ***************************************************************************
    **
    **  Performs periodic trending data broadcast.
    **
    ***************************************************************************
    */
    @Override
    public void tick()
    {
        mon.publishData();
    }


   /**
    ***************************************************************************
    **
    **  Sets the tick period.
    **
    **  Overrides the method in Module in order to publish a status update.
    **
    **  @param  value  The tick period (milliseconds) to set.
    **
    ***************************************************************************
    */
    @Command(type=CommandType.ACTION, description="Sets the tick interval")
    @Override
    public void setTickMillis(int value)
    {
        super.setTickMillis(value);
        publishState();
    }


   /**
    ***************************************************************************
    **
    **  Handles alarm events.
    **
    **  @param  event  The event type
    **
    **  @param  parm   The event parameter
    **
    ***************************************************************************
    */
    @Override
    public void processAlarm(int event, int parm)
    {
        switch (parm) {

        case EVENT_ID_MAIN_POWER:
            if (event == Alarm.EVENT_TRIP) {
                if ((state & RefrigState.MAIN_TRIPPED_STATE) == 0) {
                    state |= RefrigState.MAIN_TRIPPED_STATE;
                    setMainPowerEnable(0);
                    publishState();
                }
            }
            else if (event == Alarm.EVENT_RESET) {
                if ((state & RefrigState.MAIN_TRIPPED_STATE) != 0) {
                    state &= ~RefrigState.MAIN_TRIPPED_STATE;
                    publishState();
                }
            }
            break;
            
        case EVENT_ID_LOAD_POWER:
            if (event == Alarm.EVENT_TRIP) {
                loadAlarm = true;
                if ((state & RefrigState.LOAD_TRIP_ENAB_STATE) != 0) {
                    state &= ~RefrigState.LOAD_POWER_STATE;
                    setLoadPower();
                    publishState();
                }
            }
            else if (event == Alarm.EVENT_RESET) {
                loadAlarm = false;
                if ((state & RefrigState.LOAD_TRIP_ENAB_STATE) != 0) {
                    state |= RefrigState.LOAD_POWER_STATE;
                    setLoadPower();
                    publishState();
                }
            }
            break;

        default:

        }
    }


   /**
    ***************************************************************************
    **
    **  Sets the main power enabled state on or off.
    **
    **  @param  value    The enabled state value to set: 0 = off, ~0 = on.
    **
    ***************************************************************************
    */
    @Command(type=CommandType.ACTION,
             description="Sets the main power enabled state")
    public void setMainPowerEnable(int value)
    {
        if (value != 0) {
            if ((state & RefrigState.MAIN_TRIPPED_STATE) == 0) {
                state |= RefrigState.MAIN_POWER_STATE;
            }
        }
        else {
            state &= ~RefrigState.MAIN_POWER_STATE;
        }
        setMainPower();
        publishState();
    }


   /**
    ***************************************************************************
    **
    **  Sets the load power trip enabled state on or off.
    **
    **  @param  value  The load trip enabled state value to set: 0 = off;
    **                 ~0 = on.
    **
    ***************************************************************************
    */
    @Command(type=CommandType.ACTION,
             description="Sets the load power trip enabled state")
    public void setLoadTripEnable(int value)
    {
        if (value != 0) {
            state |= RefrigState.LOAD_TRIP_ENAB_STATE;
            if (loadAlarm) {
                state &= ~RefrigState.LOAD_POWER_STATE;
                setLoadPower();
            }
        }
        else {
            state &= ~RefrigState.LOAD_TRIP_ENAB_STATE;
            if ((state & RefrigState.LOAD_POWER_STATE) == 0) {
                state |= RefrigState.LOAD_POWER_STATE;
                setLoadPower();
            }
        }
        publishState();
    }


   /**
    ***************************************************************************
    **
    **  Saves the configuration data.
    **
    **  @throws  IOException
    **
    ***************************************************************************
    */
    @Command(type=CommandType.ACTION,
             description="Saves the current configuration")
    public void saveConfiguration() throws IOException
    {
        getEnvironment().register(configName);
        mon.clearLimitChanges();
        mon.publishState();     // Must always do this
    }


   /**
    ***************************************************************************
    **
    **  Gets the full state of the refrigeration module.
    **
    **  This is intended to be called by GUIs during initialization
    **
    **  @return  The full refrigeration state
    **
    ***************************************************************************
    */
    @Command(type=CommandType.QUERY,
             description="Gets the full refrigeration state")
    public RefrigFullState getFullState()
    {
        RefrigState refgState = new RefrigState(state, getTickMillis(), 0, 0);
        MonitorFullState monState = mon.getFullState();
        return new RefrigFullState(refgState, monState);
    }    


   /**
    ***************************************************************************
    **
    **  Gets the operating state word.
    **
    **  @return  The current value of the operating state
    **
    ***************************************************************************
    */
    int getState()
    {
        return state;
    }


   /**
    ***************************************************************************
    **
    **  Publishes the state of the refrigeration module.
    **
    **  This is intended to be called whenever any element of the state is
    **  changed.
    **
    ***************************************************************************
    */
    void publishState()
    {
        publish(RefrigState.KEY, new RefrigState(state, getTickMillis(), 0, 0));
    }    


   /**
    ***************************************************************************
    **
    **  Sets the main power on or off, according to its state.
    **
    ***************************************************************************
    */
    void setMainPower()
    {
        if (mainPowerLine != null) {
            mainPowerLine.set((state & RefrigState.MAIN_POWER_STATE) != 0);
        }
    }
            

   /**
    ***************************************************************************
    **
    **  Sets the load power on or off, according to its state.
    **
    ***************************************************************************
    */
    void setLoadPower()
    {
        if (loadPowerLine != null) {
            loadPowerLine.set((state & RefrigState.LOAD_POWER_STATE) != 0);
        }
    }


   /**
    ***************************************************************************
    **
    **  Gets the hardware main power state
    **
    ***************************************************************************
    */
    boolean isMainPowerOn()
    {
        return mainPowerLine != null && mainPowerLine.isSet();
    }
            

   /**
    ***************************************************************************
    **
    **  Gets the hardware load power state
    **
    ***************************************************************************
    */
    boolean isLoadPowerOn()
    {
        return loadPowerLine != null && loadPowerLine.isSet();
    }
    
}
